@@ -150,7 +150,7 @@ def verify(ctx, app_name, simenv_path):
     print()
 
     try:
-        manifest = load_from_manifest_db(app_name)
+        manifest = load_from_manifest_db(app_name, manifest_db_path)
         verify_manifest_format(manifest)
     except FileNotFoundError:
         print("Fatal: No manifest file for app '%s'" % app_name, file=sys.stderr)
